@@ -38,6 +38,7 @@ FILE_OPTIONS = {
                             'oslo_cache.dict',
                             'oslo_cache.mongo',
                             'oslo_cache.etcd3gw',
+                            'dogpile.cache.pymemcache',
                             'dogpile.cache.memcached',
                             'dogpile.cache.pylibmc',
                             'dogpile.cache.bmemcached',
@@ -74,9 +75,18 @@ FILE_OPTIONS = {
                          'keys/values.  Typically this should be left set '
                          'to false.'),
         cfg.ListOpt('memcache_servers', default=['localhost:11211'],
-                    help='Memcache servers in the format of "host:port".'
-                    ' (dogpile.cache.memcached and oslo_cache.memcache_pool'
-                    ' backends only).'),
+                    help='Memcache servers in the format of "host:port". '
+                         '(dogpile.cache.memcached and '
+                         'oslo_cache.memcache_pool backends only). '
+                         'If a given host refer to an IPv6 or a given domain '
+                         'refer to IPv6 then you should prefix the given '
+                         'address with the address family (``inet6``) '
+                         '(e.g ``inet6[::1]:11211``, '
+                         '``inet6:[fd12:3456:789a:1::1]:11211``, '
+                         '``inet6:[controller-0.internalapi]:11211``). '
+                         'If the address family is not given then default '
+                         'address family used will be ``inet`` which '
+                         'correspond to IPv4'),
         cfg.IntOpt('memcache_dead_retry',
                    default=5 * 60,
                    help='Number of seconds memcached server is considered dead'
@@ -101,6 +111,41 @@ FILE_OPTIONS = {
                    default=10,
                    help='Number of seconds that an operation will wait to get '
                         'a memcache client connection.'),
+        cfg.BoolOpt('memcache_pool_flush_on_reconnect',
+                    default=False,
+                    help='Global toggle if memcache will be flushed'
+                    ' on reconnect.'
+                    ' (oslo_cache.memcache_pool backend only).'),
+        cfg.BoolOpt('tls_enabled',
+                    default=False,
+                    help='Global toggle for TLS usage when comunicating with'
+                    ' the caching servers.'),
+        cfg.StrOpt('tls_cafile',
+                   default=None,
+                   help='Path to a file of concatenated CA certificates in PEM'
+                   ' format necessary to establish the caching servers\''
+                   ' authenticity. If tls_enabled is False, this option is'
+                   ' ignored.'),
+        cfg.StrOpt('tls_certfile',
+                   default=None,
+                   help='Path to a single file in PEM format containing the'
+                   ' client\'s certificate as well as any number of CA'
+                   ' certificates needed to establish the certificate\'s'
+                   ' authenticity. This file is only required when client side'
+                   ' authentication is necessary. If tls_enabled is False,'
+                   ' this option is ignored.'),
+        cfg.StrOpt('tls_keyfile',
+                   default=None,
+                   help='Path to a single file containing the client\'s'
+                   ' private key in. Otherwhise the private key will be taken'
+                   ' from the file specified in tls_certfile. If tls_enabled'
+                   ' is False, this option is ignored.'),
+        cfg.StrOpt('tls_allowed_ciphers',
+                   default=None,
+                   help='Set the available ciphers for sockets created with'
+                   ' the TLS context. It should be a string in the OpenSSL'
+                   ' cipher list format. If not specified, all OpenSSL enabled'
+                   ' ciphers will be available.'),
     ],
 }
 
@@ -111,6 +156,25 @@ def configure(conf):
             conf.register_opt(option, group=section)
 
 
+def set_defaults(conf, memcache_pool_flush_on_reconnect=False):
+    """Set defaults for configuration variables.
+
+    Overrides default options values.
+
+    :param conf: Configuration object, managed by the caller.
+    :type conf: oslo.config.cfg.ConfigOpts
+
+    :param memcache_pool_flush_on_reconnect: The default state for the
+        ``flush_on_reconnect`` flag. By default deactivated
+    :type memcache_pool_flush_on_reconnect: bool
+    """
+    conf.register_opt(FILE_OPTIONS, group='cache')
+
+    cfg.set_defaults(
+        FILE_OPTIONS,
+        memcache_pool_flush_on_reconnect=memcache_pool_flush_on_reconnect)
+
+
 def list_opts():
     """Return a list of oslo_config options.
 
